==> huaweicloudsdkdns-3.0.52-py2.py3-none-any.whl: huaweicloudsdkdns/v2/model/update_record_sets_request.py <==
# coding: utf-8

import re
import six





class UpdateRecordSetsRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'zone_id': 'str',
        'recordset_id': 'str',
        'body': 'UpdateRecordSetsReq'
    }

    attribute_map = {
        'zone_id': 'zone_id',
        'recordset_id': 'recordset_id',
        'body': 'body'
    }

    def __init__(self, zone_id=None, recordset_id=None, body=None):
        """UpdateRecordSetsRequest - a model defined in huaweicloud sdk"""
        
        

        self._zone_id = None
        self._recordset_id = None
        self._body = None
        self.discriminator = None

        self.zone_id = zone_id
        self.recordset_id = recordset_id
        if body is not None:
            self.body = body

    @property
    def zone_id(self):
        """Gets the zone_id of this UpdateRecordSetsRequest.


        :return: The zone_id of this UpdateRecordSetsRequest.
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this UpdateRecordSetsRequest.


        :param zone_id: The zone_id of this UpdateRecordSetsRequest.
        :type: str
        """
        self._zone_id = zone_id

    @property
    def recordset_id(self):
        """Gets the recordset_id of this UpdateRecordSetsRequest.


        :return: The recordset_id of this UpdateRecordSetsRequest.
        :rtype: str
        """
        return self._recordset_id

    @recordset_id.setter
    def recordset_id(self, recordset_id):
        """Sets the recordset_id of this UpdateRecordSetsRequest.


        :param recordset_id: The recordset_id of this UpdateRecordSetsRequest.
        :type: str
        """
        self._recordset_id = recordset_id

    @property
    def body(self):
        """Gets the body of this UpdateRecordSetsRequest.


        :return: The body of this UpdateRecordSetsRequest.
        :rtype: UpdateRecordSetsReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateRecordSetsRequest.


        :param body: The body of this UpdateRecordSetsRequest.
        :type: UpdateRecordSetsReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateRecordSetsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdns-3.0.53-py2.py3-none-any.whl: huaweicloudsdkdns/v2/model/update_record_sets_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateRecordSetsRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'zone_id': 'str',
        'recordset_id': 'str',
        'body': 'UpdateRecordSetsReq'
    }

    attribute_map = {
        'zone_id': 'zone_id',
        'recordset_id': 'recordset_id',
        'body': 'body'
    }

    def __init__(self, zone_id=None, recordset_id=None, body=None):
        """UpdateRecordSetsRequest - a model defined in huaweicloud sdk"""
        
        

        self._zone_id = None
        self._recordset_id = None
        self._body = None
        self.discriminator = None

        self.zone_id = zone_id
        self.recordset_id = recordset_id
        if body is not None:
            self.body = body

    @property
    def zone_id(self):
        """Gets the zone_id of this UpdateRecordSetsRequest.


        :return: The zone_id of this UpdateRecordSetsRequest.
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this UpdateRecordSetsRequest.


        :param zone_id: The zone_id of this UpdateRecordSetsRequest.
        :type: str
        """
        self._zone_id = zone_id

    @property
    def recordset_id(self):
        """Gets the recordset_id of this UpdateRecordSetsRequest.


        :return: The recordset_id of this UpdateRecordSetsRequest.
        :rtype: str
        """
        return self._recordset_id

    @recordset_id.setter
    def recordset_id(self, recordset_id):
        """Sets the recordset_id of this UpdateRecordSetsRequest.


        :param recordset_id: The recordset_id of this UpdateRecordSetsRequest.
        :type: str
        """
        self._recordset_id = recordset_id

    @property
    def body(self):
        """Gets the body of this UpdateRecordSetsRequest.


        :return: The body of this UpdateRecordSetsRequest.
        :rtype: UpdateRecordSetsReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateRecordSetsRequest.


        :param body: The body of this UpdateRecordSetsRequest.
        :type: UpdateRecordSetsReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateRecordSetsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
